@@ -135,7 +135,8 @@ class CrowdTangle:
         """
         payload = {'includeHistory': include_history}
         response = self.make_request_post(payload=payload, post_id=post_id)
-        print(respose)
+        print(response.request)
+        print(response.url)
         return response.json()
 
     def get_posts(self, accounts=None, branded_content=None, count=None, end_date=None, include_history=None,
